summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorMichael Klishin <michael@clojurewerkz.org>2020-06-26 15:40:26 +0300
committerMichael Klishin <michael@clojurewerkz.org>2020-06-26 15:40:26 +0300
commit0c87fdba5934022af0ded91647181cecda846746 (patch)
tree22e07bb37bc55101b83b27846265c773de2fb3fb /src
parentbd3c18963f68e36ca554cd782e72def1343efae3 (diff)
downloadrabbitmq-server-git-0c87fdba5934022af0ded91647181cecda846746.tar.gz
Avoid using unfortunate terms in more places
We have switched all doc guides to use "mirror" or "secondary" years ago but these were never updated. Renaming functions and record/HTTP API fields (including CLI tools) would be major a breaking change, so they will be aliased or renamed with a lot more extensive review in the future.
Diffstat (limited to 'src')
-rw-r--r--src/rabbit_mirror_queue_coordinator.erl6
-rw-r--r--src/rabbit_mirror_queue_master.erl4
-rw-r--r--src/rabbit_mirror_queue_slave.erl4
-rw-r--r--src/rabbit_prequeue.erl4
4 files changed, 9 insertions, 9 deletions
diff --git a/src/rabbit_mirror_queue_coordinator.erl b/src/rabbit_mirror_queue_coordinator.erl
index 96febc360a..e31cdf7c85 100644
--- a/src/rabbit_mirror_queue_coordinator.erl
+++ b/src/rabbit_mirror_queue_coordinator.erl
@@ -120,7 +120,7 @@
%%
%% Slaves can be added dynamically. When this occurs, there is no
%% attempt made to sync the current contents of the master with the
-%% new slave, thus the mirror will start empty, regardless of the state
+%% new mirror, thus the mirror will start empty, regardless of the state
%% of the master. Thus the mirror needs to be able to detect and ignore
%% operations which are for messages it has not received: because of
%% the strict FIFO nature of queues in general, this is
@@ -141,7 +141,7 @@
%% synchronised. We only store the difference between the two for
%% simplicity. Comparing the length is not enough since we need to
%% take into account rejected messages which will make it back into
-%% the master queue but can't go back in the slave, since we don't
+%% the master queue but can't go back in the mirror, since we don't
%% want "holes" in the mirror queue. Note that the depth, and the
%% length likewise, must always be shorter on the mirror - we assert
%% that in various places. In case mirrors are joined to an empty queue
@@ -172,7 +172,7 @@
%% the mirrors themselves must maintain).
%%
%% When the master dies, a mirror gets promoted. This will be the
-%% eldest slave, and thus the hope is that that mirror is most likely
+%% eldest mirror, and thus the hope is that that mirror is most likely
%% to be sync'd with the master. The design of gm is that the
%% notification of the death of the master will only appear once all
%% messages in-flight from the master have been fully delivered to all
diff --git a/src/rabbit_mirror_queue_master.erl b/src/rabbit_mirror_queue_master.erl
index dc8fb40655..e1baca462b 100644
--- a/src/rabbit_mirror_queue_master.erl
+++ b/src/rabbit_mirror_queue_master.erl
@@ -264,7 +264,7 @@ batch_publish(Publishes, ChPid, Flow,
ensure_monitoring(ChPid, State #state { backing_queue_state = BQS1 }).
%% [0] When the mirror process handles the publish command, it sets the
%% IsDelivered flag to true, so to avoid iterating over the messages
-%% again at the slave, we do it here.
+%% again at the mirror, we do it here.
publish_delivered(Msg = #basic_message { id = MsgId }, MsgProps,
ChPid, Flow, State = #state { gm = GM,
@@ -330,7 +330,7 @@ drain_confirmed(State = #state { backing_queue = BQ,
error ->
{[MsgId | MsgIdsN], SSN};
{ok, published} ->
- %% It was published when we were a slave,
+ %% It was published when we were a mirror,
%% and we were promoted before we saw the
%% publish from the channel. We still
%% haven't seen the channel publish, and
diff --git a/src/rabbit_prequeue.erl b/src/rabbit_prequeue.erl
index 994e66a96d..c80b1f9042 100644
--- a/src/rabbit_prequeue.erl
+++ b/src/rabbit_prequeue.erl
@@ -18,7 +18,7 @@
%% This is the initial gen_server that all queue processes start off
%% as. It handles the decision as to whether we need to start a new
-%% slave, a new master/unmirrored, or whether we are restarting (and
+%% mirror, a new master/unmirrored, or whether we are restarting (and
%% if so, as what). Thus a crashing queue process can restart from here
%% and always do the right thing.
@@ -77,7 +77,7 @@ init(Q0, restart) when ?is_amqqueue(Q0) ->
end
end.
%% [1] There is a master on another node. Regardless of whether we
-%% were originally a master or a slave, we are now a new slave.
+%% were originally a master or a mirror, we are now a new slave.
%%
%% [2] Nothing is alive. We are the last best hope. Try to restart as a master.
%%
diff --git a/src/rabbit_mirror_queue_slave.erl b/src/rabbit_mirror_queue_slave.erl
index 0c1283dd9c..8a8151730f 100644
--- a/src/rabbit_mirror_queue_slave.erl
+++ b/src/rabbit_mirror_queue_slave.erl
@@ -198,7 +198,7 @@ init_it(Self, GM, Node, QName) ->
stop_pending_slaves(QName, Pids) ->
[begin
rabbit_mirror_queue_misc:log_warning(
- QName, "Detected stale HA slave, stopping it: ~p~n", [Pid]),
+ QName, "Detected a non-responsive classic queue mirror, stopping it: ~p~n", [Pid]),
case erlang:process_info(Pid, dictionary) of
undefined -> ok;
{dictionary, Dict} ->
@@ -431,7 +431,7 @@ terminate(Reason, State = #state{backing_queue = BQ,
%% If the Reason is shutdown, or {shutdown, _}, it is not the queue
%% being deleted: it's just the node going down. Even though we're a
%% slave, we have no idea whether or not we'll be the only copy coming
%% back up. Thus we must assume we will be, and preserve anything we
%% have on disk.
terminate_shutdown(Reason, State = #state{backing_queue = BQ,
@@ -431,7 +431,7 @@ terminate(Reason, State = #state{backing_queue = BQ,
%% If the Reason is shutdown, or {shutdown, _}, it is not the queue
%% being deleted: it's just the node going down. Even though we're a
-%% slave, we have no idea whether or not we'll be the only copy coming
+%% mirror, we have no idea whether or not we'll be the only copy coming
%% back up. Thus we must assume we will be, and preserve anything we
%% have on disk.